@@ -1,27 +1,17 @@
-import os
-import json
 import datetime
-import glob
-import xml.etree.ElementTree as ET
+import json
+import os
+from typing import Any, Dict, List, Union
 
-from firstimpression.constants import TEMP_FOLDER, APIS, LOCAL_INTEGRATED_FOLDER
-from firstimpression.file import download_install_media, write_root_to_xml_files, update_directories_api, check_too_old
-from firstimpression.time import parse_date_to_string, parse_string_to_string
-from firstimpression.json import lst_dict_to_root
-from firstimpression.scala import variables, Log
 from firstimpression.api.request import request
-
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Schiphol'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.constants import APIS
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.json import lst_dict_to_root
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
+from firstimpression.time import parse_date_to_string, parse_string_to_string
+from requests import Response
 
 ##################################################################################################
 # CONSTANTS
@@ -36,18 +26,11 @@ STATIONS_JSON_FILENAME = 'stations.json'
 STATIONS_MAX_FILE_AGE = 60 * 60 * 24 * 7 * 4
 
 FLIGHTS_XML_FILENAME = 'flights.xml'
-FLIGHTS_XML_FILENAME_CONTENT = 'flights*.xml'
 FLIGHTS_MAX_FILE_AGE = 60 * 10
 
 PURGE_DIRECTORIES_DAYS = 7 * 4
 
-XML_TEMP_PATH_FLIGHTS = os.path.join(TEMP_FOLDER, NAME, FLIGHTS_XML_FILENAME)
-XML_LOCAL_PATH_FLIGHTS = os.path.join(
-    LOCAL_INTEGRATED_FOLDER, NAME, FLIGHTS_XML_FILENAME_CONTENT)
-JSON_PATH_STATIONS = os.path.join(
-    LOCAL_INTEGRATED_FOLDER, NAME, STATIONS_JSON_FILENAME)
-
-FLIGHTS_MAX = 10
+FLIGHTS_MAX = 100
 
 DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
 DATE_FORMAT = '%Y-%m-%d'
@@ -75,52 +58,69 @@ HEADERS = {
     'ResourceVersion': RESOURCE_VERSION
 }
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
+XML_TEMP_PATH_FLIGHTS = os.path.join(scala.temp_folder, FLIGHTS_XML_FILENAME)
+JSON_TEMP_PATH_STATIONS = os.path.join(
+    scala.temp_folder, STATIONS_JSON_FILENAME)
+
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
 
-def run_api(id, key):
-    debug.log('folder name: {}'.format(NAME))
-    debug.log('file paths: temp -> {}, local -> {}, local station -> {}'.format(
-        XML_TEMP_PATH_FLIGHTS, XML_LOCAL_PATH_FLIGHTS, JSON_PATH_STATIONS))
+def run_api():
+    scala.debug('folder name: {}'.format(NAME))
+    scala.debug('file paths: temp -> {}, local -> {}'.format(
+        XML_TEMP_PATH_FLIGHTS, scala.content_folder))
 
-    HEADERS['app_id'] = id
-    HEADERS['app_key'] = key
+    HEADERS['app_id'] = scala.variables['api_id']
+    HEADERS['app_key'] = scala.variables['api_key']
 
-    debug.log('app_id: {} - app_key: {}'.format(id, key))
+    scala.debug('headers: {}'.format(HEADERS))
 
-    update_directories_api(NAME, PURGE_DIRECTORIES_DAYS)
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder],
+                      max_days=PURGE_DIRECTORIES_DAYS)
+    update_placeholders()
 
-    if check_too_old(JSON_PATH_STATIONS, STATIONS_MAX_FILE_AGE*2):
+    if check_too_old(JSON_TEMP_PATH_STATIONS, STATIONS_MAX_FILE_AGE):
         page = 0
-        params = dict()
-        stations = dict()
+        params: Dict[str, Union[int, str]] = dict()
+        stations: Dict[str, str] = dict()
 
-        for i in range(100000):
+        for _ in range(100000):
             params['page'] = page
-            response, is_error = request(URL_STATIONS, HEADERS, params)
+            response = request(URL_STATIONS, HEADERS, params)
 
-            if is_error:
-                debug.log('request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
-                debug.log('No more pages found for stations')
+            if not isinstance(response, Response):
+                scala.debug(
+                    'request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
+                scala.debug('No more pages found for stations')
                 break
 
             stations.update(get_stations(response.json()))
 
             page += 1
 
-        debug.log('page of stations: {}'.format(page))
+        scala.debug('page of stations: {}'.format(page))
 
         if page == 99999:
-            warn.log('Something went probably wrong when downloading stations')
+            scala.warn(
+                'Something went probably wrong when downloading stations')
 
-        with open(JSON_PATH_STATIONS, 'w') as file:
+        with open(JSON_TEMP_PATH_STATIONS, 'w') as file:
             json.dump(stations, file)
-    else:
-        debug.log('Station file not old enough')
 
-    if check_too_old(XML_TEMP_PATH_FLIGHTS, FLIGHTS_MAX_FILE_AGE*2):
+        scala.install_content(JSON_TEMP_PATH_STATIONS)
+    else:
+        scala.debug('Station file not old enough')
+
+    if check_too_old(XML_TEMP_PATH_FLIGHTS, FLIGHTS_MAX_FILE_AGE):
         page = 0
         params = {
             'sort': '+scheduleDateTime',
@@ -129,65 +129,60 @@ def run_api(id, key):
             'fromDateTime': parse_date_to_string(datetime.datetime.now(), DATETIME_FORMAT),
             'toDateTime': parse_date_to_string(datetime.datetime.now(), DATE_FORMAT) + 'T23:59:59'
         }
-        flights = list()
+        flights: List[Dict[str, str]] = list()
 
-        debug.log(params)
+        scala.debug(str(params))
 
-        if os.path.isfile(JSON_PATH_STATIONS):
-            destinations = json.load(open(JSON_PATH_STATIONS, 'r'))
-        else:
-            error.log('The stations file does not exists.')
-            raise FileExistsError(
-                "The stations file does not exists. Run this first.")
+        stations_path = scala.find_content(
+            'Content://{}/{}'.format(NAME, STATIONS_JSON_FILENAME))
 
-        for i in range(100000):
+        destinations = json.load(open(stations_path, 'r'))
+
+        for _ in range(100000):
             params['page'] = page
-            response, is_error = request(URL_FLIGHTS, HEADERS, params)
+            response = request(URL_FLIGHTS, HEADERS, params)
 
-            if is_error:
-                debug.log('request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
-                debug.log('No more flights found.')
+            if not isinstance(response, Response):
+                scala.debug(
+                    'request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
+                scala.debug('No more flights found.')
                 break
 
             flights = parse_flights(flights, destinations, response.json())
 
             if len(flights) == FLIGHTS_MAX:
-                debug.log('Max amount of flights')
+                scala.debug('Max amount of flights')
                 break
 
             page += 1
 
-        debug.log('page of flights: {}'.format(page))
-        debug.log(flights)
+        scala.debug('page of flights: {}'.format(page))
+        scala.debug(str(flights))
 
         if len(flights) == 0:
-            warn.log('No flights saved')
+            scala.warn('No flights saved')
 
         if page == 99999:
-            warn.log('Something went probably wrong when downloading flights')
+            scala.warn('Something went probably wrong when downloading flights')
 
-        write_root_to_xml_files(lst_dict_to_root(
-            flights), XML_TEMP_PATH_FLIGHTS, NAME)
+        temp_path = scala.download_root_temp(
+            lst_dict_to_root(flights), XML_TEMP_PATH_FLIGHTS)
+        scala.install_content(temp_path)
     else:
-        debug.log('File not old enough flights')
+        scala.debug('File not old enough flights')
 
 
 def check_api():
-    svars = variables()
-    file_path = sorted(glob.glob(XML_LOCAL_PATH_FLIGHTS))
+    svars = scala.variables
 
-    if len(file_path) > 0:
-        file_path = file_path[-1]
-        debug.log('glob filepath: {}'.format(file_path))
+    file_path = scala.find_content(
+        'Content://{}/{}'.format(NAME, FLIGHTS_XML_FILENAME))
 
-        if check_too_old(file_path, FLIGHTS_MAX_FILE_AGE):
-            svars['skipscript'] = True
-            info.log('file too old')
-        else:
-            svars['skipscript'] = False
-    else:
-        warn.log('File does not exists')
+    if check_too_old(file_path, FLIGHTS_MAX_FILE_AGE*2):
         svars['skipscript'] = True
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
 ##################################################################################################
 # MEDIA FUNCTIONS
@@ -198,8 +193,8 @@ def check_api():
 # GET FUNCTIONS
 ##################################################################################################
 
-def get_stations(response):
-    stations = dict()
+def get_stations(response: Dict[str, List[Dict[str, Any]]]):
+    stations: Dict[str, str] = dict()
     for destination in response.get('destinations', []):
         if not destination.get('iata', 'null') == 'null' and not destination.get('iata', None) is None:
             name = destination.get('publicName', None)
@@ -208,27 +203,23 @@ def get_stations(response):
                 if not full_name is None:
                     stations[destination['iata']] = full_name
 
-    if len(stations) == 0:
-        error.log('No stations saved')
-        raise Exception('Schiphol: No stations saved')
-
     return stations
 
 
-def get_flight_route(flight, destinations):
+def get_flight_route(flight: Dict[str, Dict[str, str]], destinations: Dict[str, str]):
 
-    route = list()
+    route: List[str] = list()
 
     for elem in flight.get('route', {}).get('destinations', 'null'):
         location = destinations.get(elem, 'Onbekend')
         if location == 'Onbekend':
-            debug.log('location route: {}'.format(elem))
+            scala.debug('location route: {}'.format(elem))
         route.append(location)
 
     return ', '.join(route)
 
 
-def get_departure_time(flight):
+def get_departure_time(flight: Dict[str, Any]):
     dt = flight.get('scheduleDateTime', None)
     if dt is None:
         return ''
@@ -237,11 +228,11 @@ def get_departure_time(flight):
         return parse_string_to_string(dt, SCHEDULE_DATETIME_FORMAT, TIME_FORMAT)
 
 
-def get_flight_number(flight):
+def get_flight_number(flight: Dict[str, Any]) -> str:
     return flight.get('flightName', 'Onbekend')
 
 
-def get_flight_status(flight):
+def get_flight_status(flight: Dict[str, Any]) -> str:
     status = flight.get('publicFlightState', {}).get(
         'flightStates', ['null'])[0]
 
@@ -252,10 +243,10 @@ def get_flight_status(flight):
 ##################################################################################################
 
 
-def parse_flights(flights, destinations, response):
+def parse_flights(flights: List[Dict[str, str]], destinations: Dict[str, str], response: Dict[str, List[Dict[str, Any]]]):
 
     for flight_info in response.get('flights', []):
-        flight = dict()
+        flight: Dict[str, str] = dict()
         skip = False
 
         flight['route'] = get_flight_route(flight_info, destinations)
@@ -267,14 +258,14 @@ def parse_flights(flights, destinations, response):
             if flights[i]['route'] == flight['route'] and flights[i]['departure_time'] == flight['departure_time'] and flights[i]['status'] == flight['status']:
                 flights[i]['flight_number'] += ', ' + flight['flight_number']
                 skip = True
-                debug.log('flight {} is same as flight {}'.format(
+                scala.debug('flight {} is same as flight {}'.format(
                     flight['flight_number'], flights[i]['flight_number']))
 
         if not skip:
             flights.append(flight)
 
         if len(flights) == FLIGHTS_MAX:
-            debug.log('break because max amount of fligths reached')
+            scala.debug('break because max amount of fligths reached')
             break
 
     return flights
