@@ -1,20 +1,8 @@
 import datetime
-from time import time
 
 from firstimpression.constants import APIS
-from firstimpression.file import update_directories_api
-from firstimpression.scala import variables, Log
+from firstimpression.scala import ScalaPlayer
 
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Countdown'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
 
 ##################################################################################################
 # CONSTANTS
@@ -22,34 +10,41 @@ error = Log('ERROR', script)
 
 NAME = APIS['countdown']
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
 
-def check_api(end_year, end_month, end_day, end_hour, end_minute, end_second):
-    debug.log('folder name: {}'.format(NAME))
-    update_directories_api(NAME)
-    svars = variables()
-    end_date = datetime.datetime(end_year,
-                                 end_month,
-                                 end_day,
-                                 end_hour,
-                                 end_minute,
-                                 end_second
-                                 )
+def check_api():
+    scala.debug('folder name: {}'.format(NAME))
+    svars = scala.variables
+
+    year = svars['end_year']
+    month = svars['end_month']
+    day = svars['end_day']
+    hour = svars['end_hour']
+    minute = svars['end_minute']
+    second = svars['end_second']
+
+    end_date = datetime.datetime(year, month, day, hour, minute, second)
     current_date = datetime.datetime.now()
 
-    debug.log('end_date: {} - current_date: {}'.format(end_date, current_date))
+    scala.debug('end_date: {} - current_date: {}'.format(end_date, current_date))
 
     if current_date > end_date:
-        warn.log('current_date is past the end date')
+        scala.warn('current_date is past the end date')
         svars['skipscript'] = True
     else:
         svars['skipscript'] = False
         time_delta = end_date - current_date
 
-        debug.log('time difference in timedelta: {}'.format(time_delta))
+        scala.debug('time difference in timedelta: {}'.format(time_delta))
 
         days_remaining = time_delta.days
         years_remaining = days_remaining//365
@@ -63,8 +58,8 @@ def check_api(end_year, end_month, end_day, end_hour, end_minute, end_second):
         minutes_remaining = seconds_remaining//60
         seconds_remaining -= minutes_remaining * 60
 
-        debug.log('years: {} - weeks: {} - days: {} - hours: {} - minutes: {} - seconds: {}'.format(years_remaining,
-                  weeks_remaining, days_remaining, hours_remaining, minutes_remaining, seconds_remaining))
+        scala.debug('years: {} - weeks: {} - days: {} - hours: {} - minutes: {} - seconds: {}'.format(years_remaining,
+                                                                                                      weeks_remaining, days_remaining, hours_remaining, minutes_remaining, seconds_remaining))
 
         svars['remaining_year'] = years_remaining
         svars['remaining_week'] = weeks_remaining
