@@ -1,23 +1,14 @@
-import glob
 import os
 import xml.etree.ElementTree as ET
 
-from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, DUTCH_INDEX
-from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media
-from firstimpression.time import change_language, parse_string_to_string
-from firstimpression.scala import variables, Log
-from firstimpression.api.request import request
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Songkick'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.api.request import give_error_message, request
+from firstimpression.constants import APIS
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
+from firstimpression.time import parse_string_to_string
+from requests.models import Response
 
 ##################################################################################################
 # CONSTANTS
@@ -47,34 +38,51 @@ TAGS = {
     'city': 'city'
 }
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, area, max_items):
-    debug.log('folder name: {}'.format(NAME))
-    url = 'http://api.songkick.com/api/3.0/metro_areas/{}/calendar.xml'.format(area)
+
+def run_api():
+
+    api_key = scala.variables['api_key']
+    area = scala.variables['area']
+    max_items = scala.variables['max_items']
+
+    url = 'http://api.songkick.com/api/3.0/metro_areas/{}/calendar.xml'.format(
+        area)
 
     params = {
         'apikey': api_key
     }
 
-    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, '{}.xml'.format(area))
+    xml_filename = '{}.xml'.format(area)
 
-    debug.log('url: {} - temp path: {}'.format(url, xml_temp_path))
+    xml_temp_path = os.path.join(scala.temp_folder, xml_filename)
 
-    update_directories_api(NAME)
-    change_language(DUTCH_INDEX)
+    scala.debug('url: {} - temp path: {}'.format(url, xml_temp_path))
+
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
+    update_placeholders()
 
     if check_too_old(xml_temp_path, MAX_FILE_AGE):
-        response, is_error = request(url, params=params)
+        response = request(url, params=params)
 
-        if is_error:
+        if not isinstance(response, Response):
+            message = give_error_message(response)
             if response['type'] == 'ERROR':
-                error.log('request {} -> {}'.format(response['reason'], response['message']))
+                scala.error(message)
             elif response['type'] == 'WARN':
-                warn.log('request {} -> {}'.format(response['reason'], response['message']))
-            exit()
+                scala.warn(message)
+
+            raise SystemExit
 
         root = ET.fromstring(response.content)
         new_root = ET.Element("root")
@@ -83,53 +91,61 @@ def run_api(api_key, area, max_items):
             item = ET.SubElement(new_root, "event")
             ET.SubElement(item, "name").text = get_name(event)
             ET.SubElement(item, "type").text = get_type(event)
-            ET.SubElement(item, "age_restriction").text = get_age_restriction(event)
-            ET.SubElement(item, "date").text = parse_string_to_string(get_date(event), DATE_FORMAT, DATE_FORMAT_NEW)
-            ET.SubElement(item, "time").text = parse_string_to_string(get_time(event), TIME_FORMAT, TIME_FORMAT_NEW)
+            ET.SubElement(
+                item, "age_restriction").text = get_age_restriction(event)
+            ET.SubElement(item, "date").text = parse_string_to_string(
+                get_date(event), DATE_FORMAT, DATE_FORMAT_NEW)
+            ET.SubElement(item, "time").text = parse_string_to_string(
+                get_time(event), TIME_FORMAT, TIME_FORMAT_NEW)
             ET.SubElement(item, "performers").text = get_performers(event)
             ET.SubElement(item, "photo").text = get_photo(event)
             ET.SubElement(item, "venue").text = get_venue(event)
             ET.SubElement(item, "location").text = get_location(event)
 
             if len(new_root) == max_items:
-                debug.log('max amount of items breaking')
+                scala.debug('max amount of items breaking')
                 break
-        
-        write_root_to_xml_files(new_root, xml_temp_path, NAME)
+
+        temp_path = scala.download_root_temp(new_root, xml_filename)
+        scala.install_content(temp_path)
+
     else:
-        debug.log('File not old enough to update')
+        scala.debug('File not old enough to update')
 
-def check_api(area):
-    svars = variables()
 
-    file_path = sorted(glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, '{}*.xml'.format(area))))
+def check_api():
+    svars = scala.variables
 
-    if len(file_path) > 0:
-        file_path = file_path[-1]
-        debug.log('glob filepath: {}'.format(file_path))
+    area = svars['area']
 
-        if check_too_old(file_path, MAX_FILE_AGE*2):
-            svars['skipscript'] = True
-            warn.log('file too old')
-        else:
-            svars['skipscript'] = False
-    else:
-        warn.log('File does not exists')
+    xml_filename = '{}.xml'.format(area)
+
+    file_path = scala.find_content(
+        'Content://{}/{}'.format(NAME, xml_filename))
+
+    if check_too_old(file_path, MAX_FILE_AGE * 2):
         svars['skipscript'] = True
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
 ##################################################################################################
 # MEDIA FUNCTIONS
 ##################################################################################################
 
+
 def get_photo(event):
     performance = get_performances(event)[0]
 
     artist_id = get_artist_id(performance)
-    link = 'http://images.sk-static.com/images/media/profile_images/artists/{}/large_avatar'.format(artist_id)
-    media_link = download_install_media(link, TEMP_FOLDER, NAME, '{}.jpg'.format(artist_id))
+    link = 'http://images.sk-static.com/images/media/profile_images/artists/{}/large_avatar'.format(
+        artist_id)
+
+    temp_path = scala.download_media_temp(link, '{}.jpg'.format(artist_id))
+    media_link = scala.install_content(temp_path)
 
     if media_link is None:
-        debug.log('No image found using placeholder instead')
+        scala.debug('No image found using placeholder instead')
         return 'Content:\\placeholders\\img.png'
     else:
         return media_link
@@ -138,18 +154,23 @@ def get_photo(event):
 # GET FUNCTIONS
 ##################################################################################################
 
+
 def get_name(event):
     return event.get(TAGS['name'], '')
 
+
 def get_type(event):
     return event.get(TAGS['type'], '')
 
+
 def get_age_restriction(event):
     return event.get(TAGS['age_restriction'], '')
 
+
 def get_start_date(event):
     return event.find(TAGS['start_date'])
 
+
 def get_date(event):
     start_date = get_start_date(event)
 
@@ -158,6 +179,7 @@ def get_date(event):
     else:
         return ''
 
+
 def get_time(event):
     start_date = get_start_date(event)
 
@@ -166,15 +188,19 @@ def get_time(event):
     else:
         return ''
 
+
 def get_performances(event):
     return event.findall(TAGS['performance'])
 
+
 def get_artist_id(performance):
     return performance.get(TAGS['id'], None)
 
+
 def get_artist_name(performance):
     return performance.get(TAGS['name'], None)
 
+
 def get_performers(event):
     performances = get_performances(event)
     performers = list()
@@ -184,12 +210,14 @@ def get_performers(event):
 
         if not artist_id is None:
             performers.append(get_artist_name(performance))
-    
+
     return ' + '.join(performers)
 
+
 def get_venue(event):
     return event.find(TAGS['venue']).get(TAGS['name'], '')
 
+
 def get_location(event):
     return event.find(TAGS['location']).get(TAGS['city'], '').split(',').pop(0)
 
