@@ -173,7 +173,8 @@ class ScalaPlayer:
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as e:
-            self.error('{}'.format(e))
+            self.error('Downloading image {} did not work because requests raised response error {}'.format(
+                media_link, str(e)))
 
         with open(media_path, 'wb') as f:
             shutil.copyfileobj(response.raw, f)
@@ -258,7 +259,8 @@ class ScalaPlayer:
                 item.lockObj = lockObj
                 return item
             except com_error as error:
-                self.error(str(error))
+                self.error('error while locking content {} because of com_error {}'.format(
+                    path, str(error)))
 
         else:
             print('Locking content')
